@@ -109,8 +109,8 @@ int pam_sm_chauthtok(pam_handle_t *pamh, int flags, int argc, const char **argv)
                 char *current_domain = textdomain(NULL);
                 textdomain("deepin-pw-check");
 
-                sprintf(outbuf, gettext("Bad password: %s"), err_to_string((PW_ERROR_TYPE)ret));
-                printf("%s\n", outbuf);
+                sprintf(outbuf, err_to_string((PW_ERROR_TYPE)ret));
+                pam_error(pamh, "%s", outbuf);
                 pam_set_item(pamh, PAM_AUTHTOK, NULL);
 
                 setlocale(LC_ALL, "");
